@@ -75,8 +75,7 @@ class InternetDynamicFields(ProvisionDynamicFields):
         return DynamicField(name="NIFNIEtitular", value=self.service_data.previous_owner_vat)
 
     def _notes(self):
-        if self.service_data.notes:
-            return DynamicField(name="notes", value=self.service_data.notes)
+        return DynamicField(name="notes", value=self.service_data.notes)
 
     def _adsl_coverage(self):
         return DynamicField(name="coberturaADSL", value=self.service_data.adsl_coverage)
@@ -98,3 +97,9 @@ class InternetDynamicFields(ProvisionDynamicFields):
 
     def _change_address_provider(self):
         return DynamicField(name="proveidorPreviCU", value=self.service_data.previous_internal_provider)
+
+    def _product(self):
+        return DynamicField(
+            name="productBA",
+            value=self.service_data.product
+        )
