@@ -18,8 +18,6 @@ class TicketFactoryIntegrationTestCase(unittest.TestCase):
             'phone_number',
             'sc_icc',
             'icc',
-            'service_minutes',
-            'service_internet',
             'portability',
             'previous_provider',
             'previous_owner_name',
@@ -81,8 +79,6 @@ class TicketFactoryIntegrationTestCase(unittest.TestCase):
             'mm_fiber_coverage',
             'vdf_fiber_coverage',
             'change_address',
-            'landline_type',
-            'landline_minutes',
             'landline_phone_number',
             'product',
             'previous_internal_provider',
@@ -133,7 +129,6 @@ class TicketFactoryIntegrationTestCase(unittest.TestCase):
             'mm_fiber_coverage',
             'vdf_fiber_coverage',
             'change_address',
-            'internet_speed',
             'product',
             'previous_internal_provider',
         ])
