@@ -89,8 +89,6 @@ class ADSLTicketTestCase(unittest.TestCase):
             'mm_fiber_coverage',
             'vdf_fiber_coverage',
             'change_address',
-            'landline_type',
-            'landline_minutes',
             'landline_phone_number',
             'product',
             'previous_internal_provider',
