@@ -29,7 +29,6 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
             'order_id',
             'iban',
             'phone_number',
-            'internet_speed',
             'service_address',
             'service_city',
             'service_zip',
@@ -428,21 +427,6 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["canviUbicacioMateixTitular"], "no")
 
-# Service Dynamic Fields
-
-    def test_speed_field(self):
-        self.service_data.internet_speed = "120MB"
-
-        dynamic_fields = FiberDynamicFields(
-            self.service_data,
-            self.customer_data,
-            self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
-        ).all()
-
-        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
-        self.assertEqual(dynamic_fields_dct["velocitatSollicitada"], "120MB")
-
     def test_product_field(self):
         self.service_data.product = "FIBRA100"
 
@@ -454,7 +438,7 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
-        self.assertEqual(dynamic_fields_dct["product"], "FIBRA100")
+        self.assertEqual(dynamic_fields_dct["productBA"], "FIBRA100")
 
     def test_previous_provider_CU_field(self):
         self.service_data.previous_internal_provider = "SC-MM"
