@@ -75,8 +75,6 @@ class MobileTicketTestCase(unittest.TestCase):
             'phone_number',
             'sc_icc',
             'icc',
-            'service_minutes',
-            'service_internet',
             'portability',
             'previous_provider',
             'previous_owner_vat',
@@ -85,7 +83,6 @@ class MobileTicketTestCase(unittest.TestCase):
             'product',
         ])
         mobile_data.order_id = 4321
-        mobile_data.service_minutes = '0'
         mobile_data.portability = False
 
         customer_data = Mock(spec=[
@@ -125,8 +122,6 @@ class MobileTicketTestCase(unittest.TestCase):
             'phone_number',
             'sc_icc',
             'icc',
-            'service_minutes',
-            'service_internet',
             'portability',
             'previous_provider',
             'previous_owner_vat',
